@@ -1,4 +1,4 @@
-## ---- include = FALSE---------------------------------------------------------
+## ----include = FALSE----------------------------------------------------------
 knitr::opts_chunk$set(
   collapse = TRUE,
   comment = "#>",
@@ -28,7 +28,7 @@ fl_lm <- flashlight(
 fl_lm |> 
   light_performance() |> 
   plot(fill = "darkred") +
-  labs(x = element_blank(), title = "Performance on training data")
+  labs(x = NULL, title = "Performance on training data")
 
 fl_lm |> 
   light_performance(by = "Species") |> 
